import { jsx } from '@emotion/core';
import { useCallback } from 'react';
import _pt from 'prop-types';
import { useConnectedField } from '../hooks/useConnectedField.esm.js';
import { CheckboxGroupFieldBlock } from './CheckboxGroupFieldBlock.esm.js';

const CheckboxGroupConnectedField = props => {
  const [connectedProps, _field, _meta, helpers] = useConnectedField(props.name);
  const value = connectedProps.value || [];
  const handleChange = useCallback(e => {
    const target = e.currentTarget;
    let newValue;

    if (target.checked) {
      newValue = [...value, target.value];
    } else {
      newValue = value.filter(optionValue => optionValue !== target.value);
    }

    helpers.setValue(newValue);
  }, [value, helpers.setValue]);
  const handleBlur = useCallback(() => {
    helpers.setTouched(true);
  }, [helpers.setTouched]);
  return jsx(CheckboxGroupFieldBlock, { ...connectedProps,
    ...props,
    onChange: handleChange,
    onBlur: handleBlur
  });
};
CheckboxGroupConnectedField.propTypes = {
  name: _pt.string.isRequired,
  id: _pt.string,
  label: _pt.node,
  value: _pt.arrayOf(_pt.string)
};

export { CheckboxGroupConnectedField };
//# sourceMappingURL=CheckboxGroupConnectedField.esm.js.map
