import { jsx } from '@emotion/core';
import { forwardRef } from 'react';
import { useAriaFormField } from '../../form-skeletons/hooks/useAriaFormField.esm.js';
import { FormFieldBlockBoilerplate } from './FormFieldBlock.esm.js';
import { StyledInput } from './styled-primitives/StyledInput.esm.js';

/** @jsx jsx */
const InputFieldBlock = /*#__PURE__*/forwardRef(function InputFieldBlock(props, ref) {
  const {
    id,
    label,
    labelSize,
    error,
    hint,
    className,
    validationMode,
    layout,
    required,
    ...rest
  } = props;
  const fieldData = useAriaFormField(id, {
    required: required,
    hasError: !!error,
    hasHint: !!hint,
    validationMode
  });
  return jsx(FormFieldBlockBoilerplate, {
    fieldData: fieldData,
    id: id,
    label: label,
    error: error,
    hint: hint,
    labelSize: labelSize,
    layout: layout,
    className: className
  }, jsx(StyledInput, {
    ref: ref,
    ...fieldData.controlProps,
    css: {
      width: `100%`
    },
    ...rest
  }));
});

export { InputFieldBlock };
//# sourceMappingURL=InputFieldBlock.esm.js.map
