import { useMemo } from 'react';
import Case from 'case';
import { useField, useFormikContext } from 'formik';

function useConnectedField(propsOrFieldName) {
  const name = typeof propsOrFieldName === `string` ? propsOrFieldName : propsOrFieldName.name;
  const id = `${name}Field`;
  const label = Case.sentence(name);
  const [field, meta, helpers] = useFieldFast(propsOrFieldName);
  const connectedProps = { ...field,
    id,
    label,
    error: meta.touched ? meta.error : ""
  };
  return [connectedProps, field, meta, helpers];
}
/**
 * Taken from this comment in Formik's issues:
 * https://github.com/formium/formik/issues/2268#issuecomment-682685788
 */

function useFieldFast(propsOrFieldName) {
  const [field, meta] = useField(propsOrFieldName); // `setField*` helpers from `useFormikContext` seem to be more "stable" than the ones returned by `useField`

  const {
    setFieldTouched,
    setFieldValue,
    setFieldError
  } = useFormikContext(); // so we are going to shim field level helpers using them and `useMemo`:

  const helpers = useMemo(() => ({
    setValue: (...args) => setFieldValue(field.name, ...args),
    setTouched: (...args) => setFieldTouched(field.name, ...args),
    // Seems like Formik's type defs for `setError` are incorrectly expecting the argument to have type TValue instead of a string
    // @ts-expect-error
    setError: (...args) => setFieldError(field.name, ...args)
  }), [setFieldTouched, setFieldValue, setFieldError, field.name]);
  return [field, meta, helpers];
}

export { useConnectedField };
//# sourceMappingURL=useConnectedField.esm.js.map
